@@ -523,14 +523,16 @@ class Executor:
 			increment = oldvalues[1]
 		if minvalue is None:
 			minvalue = oldvalues[0]
-		seqvalue = oldvalues[2]
+		self.cursor.execute("select {}.nextval from dual".format(sequence))
+		seqvalue = self.cursor.fetchone()[0]
 
 		# Fetch information about the table values
-		self.cursor.execute("select nvl(max({}), {}) from {}".format(field, minvalue, table))
+		self.cursor.execute("select nvl(max({}), 0) from {}".format(field, table))
 		tabvalue = self.cursor.fetchone()[0]
 
-		if tabvalue != seqvalue:
-			self.cursor.execute("alter sequence {} increment by {}".format(sequence, tabvalue-seqvalue+increment))
+		step = max(tabvalue, minvalue) - seqvalue
+		if step:
+			self.cursor.execute("alter sequence {} increment by {}".format(sequence, step))
 			self.cursor.execute("select {}.nextval from dual".format(sequence))
 			seqvalue = self.cursor.fetchone()[0]
 			self.cursor.execute("alter sequence {} increment by {}".format(sequence, increment))
@@ -611,12 +613,15 @@ class Executor:
 
 	def _printsummary(self):
 		if self.verbose >= 2:
-			l1 = len(str(max(self.commandcounts.values())))
+			commandcountvalues = self.commandcounts.values()
+			l1 = len(str(max(commandcountvalues))) if commandcountvalues else 0
 			l2 = max(len(procname) for procname in self.procedurecounts) if self.procedurecounts else 0
 			print()
 			print("Summary")
 			print("=======")
+			anyoutput = False
 			if self.commandcounts["procedure"]:
+				anyoutput = True
 				print("{:>{}} type".format("#", l1))
 				print("{} {}".format("-"*l1, "-"*l2))
 				for (procname, count) in sorted(self.procedurecounts.items(), key=operator.itemgetter(1)):
@@ -624,7 +629,10 @@ class Executor:
 				print("{} {}".format("-"*l1, "-"*l2))
 			for cmdtype in ("procedure", "sql", "file", "scp", "resetsequence"):
 				if self.commandcounts[cmdtype]:
+					anyoutput = True
 					print("{:>{}} ({}s)".format(self.commandcounts[cmdtype], l1, cmdtype))
+			if not anyoutput:
+				print("no commands executed")
 
 	def _formatargs(self, command):
 		args = []
@@ -641,7 +649,10 @@ class Executor:
 		return "{}({})".format(command["name"], self._formatargs(command))
 
 	def _formatsql(self, command):
-		return "{!r} with args {}".format(command["sql"], self._formatargs(command))
+		if "args" in command and command["args"]:
+			return "{!r} with args {}".format(command["sql"], self._formatargs(command))
+		else:
+			return repr(command["sql"])
 
 
 
