@@ -1,17 +1,17 @@
 # -*- coding: utf-8 -*-
+# cython: language_level=3, always_allow_keywords=True
 
-## Copyright 1999-2008 by LivingLogic AG, Bayreuth/Germany
-## Copyright 1999-2008 by Walter Dörwald
+## Copyright 1999-2014 by LivingLogic AG, Bayreuth/Germany
+## Copyright 1999-2014 by Walter Dörwald
 ##
 ## All Rights Reserved
 ##
-## See xist/__init__.py for the license
+## See ll/xist/__init__.py for the license
 
 
 """
-<p>An &xist; module that contains elements that are useful for
-forms. These are just abbreviations for the various
-<lit>&lt;input type=<rep>...</rep>&gt;</lit> elements.</p>
+This XIST module contains convenience classes for form elements. These are
+just abbreviations for the various ``<input type="...">`` elements.
 """
 
 
@@ -19,29 +19,29 @@ from ll.xist import xsc
 from ll.xist.ns import html
 
 
-__docformat__ = "xist"
+__docformat__ = "reStructuredText"
 
 
 xmlns = "http://xmlns.livinglogic.de/xist/ns/form"
 
 
+class text(html.input):
+	xmlns = xmlns
+	class Attrs(html.input.Attrs):
+		type = None
+
+	def convert(self, converter):
+		e = html.input(self.attrs, type="text")
+		return e.convert(converter)
+
+
 class checkbox(html.input):
 	xmlns = xmlns
 	class Attrs(html.input.Attrs):
 		type = None
 
 	def convert(self, converter):
-		e = html.input(self.attrs, type=u"checkbox")
-		return e.convert(converter)
-
-
-class edit(html.input):
-	xmlns = xmlns
-	class Attrs(html.input.Attrs):
-		type = None
-
-	def convert(self, converter):
-		e = html.input(self.attrs, type=u"text")
+		e = html.input(self.attrs, type="checkbox")
 		return e.convert(converter)
 
 
@@ -51,7 +51,17 @@ class radio(html.input):
 		type = None
 
 	def convert(self, converter):
-		e = html.input(self.attrs, type=u"radio")
+		e = html.input(self.attrs, type="radio")
+		return e.convert(converter)
+
+
+class file(html.input):
+	xmlns = xmlns
+	class Attrs(html.input.Attrs):
+		type = None
+
+	def convert(self, converter):
+		e = html.input(self.attrs, type="file")
 		return e.convert(converter)
 
 
@@ -61,17 +71,27 @@ class submit(html.input):
 		type = None
 
 	def convert(self, converter):
-		e = html.input(self.attrs, type=u"submit")
+		e = html.input(self.attrs, type="submit")
 		return e.convert(converter)
 
 
-class memo(html.textarea):
+class button(html.input):
+	xmlns = xmlns
+	class Attrs(html.input.Attrs):
+		type = None
+
+	def convert(self, converter):
+		e = html.input(self.attrs, type="button")
+		return e.convert(converter)
+
+
+class textarea(html.textarea):
 	xmlns = xmlns
 	class Attrs(html.textarea.Attrs):
 		class value(xsc.TextAttr): pass
 
 	def convert(self, converter):
-		e = html.textarea(self[u"value"], self.attrs.withoutnames(u"value"))
+		e = html.textarea(self.attrs.value, self.attrs.withoutnames("value"))
 		return e.convert(converter)
 
 
@@ -80,9 +100,9 @@ class hidden(html.input):
 	class Attrs(html.input.Attrs):
 		type = None
 
-	def __unicode__(self):
-		return u""
+	def __str__(self):
+		return ""
 
 	def convert(self, converter):
-		e = html.input(self.attrs, type=u"hidden")
+		e = html.input(self.attrs, type="hidden")
 		return e.convert(converter)
